==> nodestream-0.8.13-py3-none-any.whl: nodestream/databases/neo4j/query.py <==
from dataclasses import dataclass
from typing import Any, Dict, List

UNWIND_QUERY = "UNWIND $batched_parameter_sets as params RETURN params"
COMMIT_QUERY = """
CALL apoc.periodic.iterate(
    $iterable_query,
    $batched_query,
    {batchsize: 1000, parallel: true, retries: 3, params: $iterate_params}
)
YIELD batches, committedOperations, failedOperations, errorMessages
RETURN batches, committedOperations, failedOperations, errorMessages
"""


@dataclass(slots=True, frozen=True)
class Query:
    query_statement: str
    parameters: Dict[str, Any]

    @classmethod
    def from_statement(cls, statement: str):
        return cls(query_statement=statement, parameters={})

    def feed_batched_query(self, batched_query: str) -> "Query":
        """Feed the results of the the query into another query that will be executed in batches."""
        return Query(
            COMMIT_QUERY,
            {
                "iterate_params": self.parameters,
                "batched_query": batched_query,
                "iterable_query": self.query_statement,
            },
        )


@dataclass(slots=True, frozen=True)
class QueryBatch:
    query_statement: str
    batched_parameter_sets: List[Dict[str, Any]]

    def as_query(self) -> Query:
        return Query(
            COMMIT_QUERY,
            {
                "iterate_params": {
                    "batched_parameter_sets": self.batched_parameter_sets
                },
                "batched_query": self.query_statement,
                "iterable_query": UNWIND_QUERY,
            },
        )

==> nodestream-0.11.11a0-py3-none-any.whl: nodestream/databases/neo4j/query.py <==
from dataclasses import dataclass
from typing import Any, Dict, List

UNWIND_QUERY = "UNWIND $batched_parameter_sets as params RETURN params"
COMMIT_QUERY = """
CALL apoc.periodic.iterate(
    $iterable_query,
    $batched_query,
    {batchSize: $chunk_size, parallel: $execute_chunks_in_paralell, retries: $retries_per_chunk, params: $iterate_params}
)
YIELD batches, committedOperations, failedOperations, errorMessages
RETURN batches, committedOperations, failedOperations, errorMessages
"""

NON_APOCH_COMMIT_QUERY = """
UNWIND $iterate_params.batched_parameter_sets AS param
CALL apoc.cypher.doIt($batched_query, {params: param})
YIELD value
RETURN value
"""


@dataclass(slots=True, frozen=True)
class Query:
    query_statement: str
    parameters: Dict[str, Any]

    @classmethod
    def from_statement(cls, statement: str):
        return cls(query_statement=statement, parameters={})

    def feed_batched_query(self, batched_query: str) -> "Query":
        """Feed the results of the the query into another query that will be executed in batches."""
        return Query(
            COMMIT_QUERY,
            {
                "iterate_params": self.parameters,
                "batched_query": batched_query,
                "iterable_query": self.query_statement,
            },
        )


@dataclass(slots=True, frozen=True)
class QueryBatch:
    query_statement: str
    batched_parameter_sets: List[Dict[str, Any]]

    def as_query(
        self,
        apoc_iterate: bool,
        chunk_size: int = 1000,
        execute_chunks_in_paralell: bool = True,
        retries_per_chunk: int = 3,
    ) -> Query:
        return Query(
            {True: COMMIT_QUERY, False: NON_APOCH_COMMIT_QUERY}[apoc_iterate],
            {
                "iterate_params": {
                    "batched_parameter_sets": self.batched_parameter_sets
                },
                "batched_query": self.query_statement,
                "iterable_query": UNWIND_QUERY,
                "execute_chunks_in_paralell": execute_chunks_in_paralell,
                "chunk_size": chunk_size,
                "retries_per_chunk": retries_per_chunk,
            },
        )
